/*
 * Copyright 2002 Eric Hodel. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgement:
 *    This product includes software developed by Eric Hodel and
 *    his contributors.
 * 4. Neither the name of Eric Hodel nor the names of his
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ERIC HODEL AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL ERIC HODEL OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

const PASSWORD_CID = "@mozilla.org/passwordmanager;1";
const PREF_CID = "@mozilla.org/preferences;1";
const STRINGBUNDLE_CID = "@mozilla.org/intl/stringbundle;1";

var gPasswordManager;
var gPasswordManagerInternal;
var gPreferences;
var gStringBundle
var gStatusText;

function getString(name) {
  if (!gStringBundle) {
    try {
      var strBundleService = Components.classes[STRINGBUNDLE_CID].getService()
      strBundleService = QueryInterface(Components.interfaces.nsIStringBundleService);
      gStringBundle = strBundleService.createBundle("chrome://livelizard/locale/livelizard.properties");
    } catch (e) {}
  }

  if (gStringBundle) {
    try {
      return gStringBundle.GetStringFromName(name);
    } catch (e) {}
  }
  return "";
}

function getPref() {
  if (!gPreferences) {
    try {
      gPreferences = Components.classes[PREF_CID].getService();
      gPreferences = gPreferences.QueryInterface(
        Components.interfaces.nsIPref);
    } catch (e) {}
  }

  return gPreferences;
}

function getPasswordManager() {
  if (!gPasswordManager) {
    try {
      gPasswordManager = Components.classes[PASSWORD_CID].getService();
      gPasswordManager = gPasswordManager.QueryInterface(
        Components.interfaces.nsIPasswordManager);
    } catch (e) {
      dump("getPasswordManager() failed\n");
    }
  }

  return gPasswordManager;
}

function getPasswordManagerInternal() {
  if (!gPasswordManagerInternal) {
    try {
      gPasswordManagerInternal =
        Components.classes[PASSWORD_CID].getService();
      gPasswordManagerInternal = gPasswordManagerInternal.QueryInterface(
        Components.interfaces.nsIPasswordManagerInternal);
    } catch (e) {
      dump("getPasswordManagerInternal() failed\n");
    }
  }

  return gPasswordManagerInternal;
}

function getPassword(loginData) {
  if (!loginData)
    return null;

  var pmInternal = getPasswordManagerInternal();
  if (!pmInternal)
    return null;

  var host = {value:''};
  var user = {value:''};
  var password = {value:''};

  try {
    pmInternal.findPasswordEntry(loginData.ljURL, '', '',
      host, user, password);
    loginData.username = user.value;
    loginData.password = password.value;
    return loginData;
  } catch(e) {
    dump("findPasswordEntry() failed\n");
  }

  return null;
}

function savePassword(loginData) {
  if (!loginData || !loginData.ljURL || !loginData.username)
    return false;

  var pm = getPasswordManager();

  if (!pm)
    return false;

  try {
    pm.removeUser(loginData.ljURL, loginData.username);
  } catch(e) {
    dump("removeUser() failed\n");
  }

  if (loginData.savePassword) {
    try {
      pm.addUser(loginData.ljURL, loginData.username, loginData.password);
    } catch(e) {
      dump("addUser failed\n");
    }

    return true;
  }
  
  return false;
}

function setStatusText(text) {
  if (!gStatusText) {
    gStatusText = document.getElementById('statusText');
  }
  
  gStatusText.label = text;
}

function spellCheck() {
  var text = gEditor.content;
  var textArr = text.split(/<(\/)?([^<>]+)>/);
  if (false) {
  var tempArr = [];

  var word, i;
  var origArr = [];
  var checkArr = [];
  var origString = "";

  dump("[");
  for (word in textArr) {
    dump(word + ", ");
  }
  dump("]\n");

  for (i = 0; i < textArr.length; i++) {
    word = textArr[i];

    if (word == undefined) {
      dump("undefined\n");
      tempArr[tempArr.length - 1] = textArr[i];
    } else if (word == '/') {
      dump("tag\n");
      tempArr[tempArr.length - 1] = textArr[i];
    } else {
      dump("wordlist: " + word + "\n");
      tempArr.concat = word.split(' ');
    }
  }

  dump("tempArr.length: " + tempArr.length + "\n");

  textArr = tempArr;

  for (i = 0; i < textArr.length; i++) {
    word = textArr[i];
    dump("word: " + word + "\n");
    /*
     * finding an undefined or '/' means that the next item
     * will be an open or closing element
     */
    if (word == undefined || word == '/') {
      i += 2;
    } else {
      origArr[origArr.length - 1] = [word, i];
    }

    /* XXX: stop using nativeSpellCheck */
    if (origArr.length == 10) {
      for (word in origArr) {
        origString += word[0] + " ";
      }
      
      //checkArr = gGoogleAPI.nativeSpellCheck(origString).split(" ");
      checkArr = origString.split(" ");

      for (i = 0; i < origArr.lenght; i++) {
        if (checkArr[i] != origArr[i][0]) {
          /* TODO: confirm UI */
          alert("Replacing " + origArr[i][0] + " with " + checkArr[i]);
          textArr[origArr[i][1]] = checkArr[i];
        }
      }

      origArr = [];
    }
  }

  /* now we've checked the whole thing */
  text = "";
  for (i = 0; i < textArr.length; i++) {
    word = textArr[i];

    if (word == undefined) {
      text += "<" + textArr[++i] + ">";
    } else if (word == '/') {
      text += "</" + textArr[++i] + ">";
    } else {
      text += word + " ";
    }
  }
  } /* if (false) */
  
  dump("checked: " + text + "\n");
  return text;
}
